package com.bonus.canteen.core.device.mapper;

import java.util.List;
import com.bonus.canteen.core.device.domain.DeviceBind;

/**
 * 设备绑定多档口子Mapper接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface DeviceBindMapper {
    /**
     * 查询设备绑定多档口子
     * 
     * @param id 设备绑定多档口子主键
     * @return 设备绑定多档口子
     */
    public DeviceBind selectDeviceBindById(Long id);

    /**
     * 查询设备绑定多档口子列表
     * 
     * @param deviceBind 设备绑定多档口子
     * @return 设备绑定多档口子集合
     */
    public List<DeviceBind> selectDeviceBindList(DeviceBind deviceBind);

    /**
     * 新增设备绑定多档口子
     * 
     * @param deviceBind 设备绑定多档口子
     * @return 结果
     */
    public int insertDeviceBind(DeviceBind deviceBind);

    /**
     * 修改设备绑定多档口子
     * 
     * @param deviceBind 设备绑定多档口子
     * @return 结果
     */
    public int updateDeviceBind(DeviceBind deviceBind);

    /**
     * 删除设备绑定多档口子
     * 
     * @param id 设备绑定多档口子主键
     * @return 结果
     */
    public int deleteDeviceBindById(Long id);

    /**
     * 批量删除设备绑定多档口子
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDeviceBindByIds(Long[] ids);
}
