package com.bonus.canteen.core.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.device.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.device.domain.DeviceBind;
import com.bonus.canteen.core.device.service.IDeviceBindService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 设备绑定多档口子Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "设备绑定多档口子接口")
@RestController
@RequestMapping("/device_bind")
public class DeviceBindController extends BaseController {
    @Autowired
    private IDeviceBindService deviceBindService;

    /**
     * 查询设备绑定多档口子列表
     */
    @ApiOperation(value = "查询设备绑定多档口子列表")
    //@RequiresPermissions("device:bind:list")
    @GetMapping("/list")
    public TableDataInfo list(DeviceBind deviceBind) {
        startPage();
        List<DeviceBind> list = deviceBindService.selectDeviceBindList(deviceBind);
        return getDataTable(list);
    }

    /**
     * 导出设备绑定多档口子列表
     */
    @ApiOperation(value = "导出设备绑定多档口子列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("device:bind:export")
    @SysLog(title = "设备绑定多档口子", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出设备绑定多档口子")
    @PostMapping("/export")
    public void export(HttpServletResponse response, DeviceBind deviceBind) {
        List<DeviceBind> list = deviceBindService.selectDeviceBindList(deviceBind);
        ExcelUtil<DeviceBind> util = new ExcelUtil<DeviceBind>(DeviceBind.class);
        util.exportExcel(response, list, "设备绑定多档口子数据");
    }

    /**
     * 获取设备绑定多档口子详细信息
     */
    @ApiOperation(value = "获取设备绑定多档口子详细信息")
    //@RequiresPermissions("device:bind:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(deviceBindService.selectDeviceBindById(id));
    }

    /**
     * 新增设备绑定多档口子
     */
    @ApiOperation(value = "新增设备绑定多档口子")
    //@PreventRepeatSubmit
    //@RequiresPermissions("device:bind:add")
    @SysLog(title = "设备绑定多档口子", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增设备绑定多档口子")
    @PostMapping
    public AjaxResult add(@RequestBody DeviceBind deviceBind) {
        try {
            return toAjax(deviceBindService.insertDeviceBind(deviceBind));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改设备绑定多档口子
     */
    @ApiOperation(value = "修改设备绑定多档口子")
    //@PreventRepeatSubmit
    //@RequiresPermissions("device:bind:edit")
    @SysLog(title = "设备绑定多档口子", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改设备绑定多档口子")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody DeviceBind deviceBind) {
        try {
            return toAjax(deviceBindService.updateDeviceBind(deviceBind));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除设备绑定多档口子
     */
    @ApiOperation(value = "删除设备绑定多档口子")
    //@PreventRepeatSubmit
    //@RequiresPermissions("device:bind:remove")
    @SysLog(title = "设备绑定多档口子", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除设备绑定多档口子")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(deviceBindService.deleteDeviceBindByIds(ids));
    }
}
